@@ -4,7 +4,10 @@ import time
 from functools import wraps
 import logging
 
+from decorators import classproperty
+
 from .exception import InterfaceError
+from .compat import *
 
 
 logger = logging.getLogger(__name__)
@@ -23,7 +26,7 @@ def reconnecting(count=None, backoff=None):
     count -- integer -- how many attempts to run the method, defaults to 3
     backoff -- float -- how long to sleep on failure, defaults to 1.0
     """
-    # we get trixxy here so we can manipulate these values in the wrapped function,
+    # we get tricksy here so we can manipulate these values in the wrapped function,
     # this is one of the first times I wish we were on Python 3
     # http://stackoverflow.com/a/9264845/5006
     reconn_params = {
@@ -60,7 +63,7 @@ def reconnecting(count=None, backoff=None):
                     return func(self, *args, **kwargs)
 
                 except InterfaceError as e:
-                    e_msg = str(e.e)
+                    e_msg = String(e.e)
                     # TODO -- this gets us by SQLite and Postgres, but might not
                     # work in the future, so this needs to be a tad more robust
                     if "closed" in e_msg.lower():
@@ -80,26 +83,3 @@ def reconnecting(count=None, backoff=None):
 
     return retry_decorator
 
-
-class classproperty(property):
-    """
-    allow a class property to exist on the Orm
-
-    NOTE -- this is read only, you can't write to the property
-
-    example --
-
-        class Foo(object):
-            @classproperty
-            def bar(cls):
-                return 42
-
-        Foo.bar # 42
-
-    http://stackoverflow.com/questions/128573/using-property-on-classmethods
-    http://stackoverflow.com/questions/5189699/how-can-i-make-a-class-property-in-python
-    http://docs.python.org/2/reference/datamodel.html#object.__setattr__
-    """
-    def __get__(self, instance, cls):
-        return self.fget(cls)
-
