@@ -33,6 +33,8 @@ try:
 except ImportError:
     thread = None
 
+from datatypes import Datetime
+
 # first party
 from ..exception import UniqueError
 from ..compat import *
@@ -251,16 +253,19 @@ class SQLite(SQLInterface):
 
         # for some reason this is needed in python 3.6 in order for saved bytes
         # to be ran through the converter, not sure why
-        sqlite3.register_converter('TEXT' if not is_py2 else b'TEXT', StringType.adapt)
+        sqlite3.register_converter(b'TEXT' if is_py2 else 'TEXT', StringType.adapt)
 
         sqlite3.register_adapter(decimal.Decimal, NumericType.adapt)
-        sqlite3.register_converter('NUMERIC' if not is_py2 else b'NUMERIC', NumericType.convert)
+        sqlite3.register_converter(b'NUMERIC' if is_py2 else 'NUMERIC', NumericType.convert)
 
         sqlite3.register_adapter(bool, BooleanType.adapt)
-        sqlite3.register_converter('BOOLEAN' if not is_py2 else b'BOOLEAN', BooleanType.convert)
+        sqlite3.register_converter(b'BOOLEAN' if is_py2 else 'BOOLEAN', BooleanType.convert)
 
+        # sadly, it doesn't look like these work for child classes so each class
+        # has to be adapted even if its parent is already registered
         sqlite3.register_adapter(datetime.datetime, TimestampType.adapt)
-        sqlite3.register_converter('TIMESTAMP' if not is_py2 else b'TIMESTAMP', TimestampType.convert)
+        sqlite3.register_adapter(Datetime, TimestampType.adapt)
+        sqlite3.register_converter(b'TIMESTAMP' if is_py2 else 'TIMESTAMP', TimestampType.convert)
 
         # turn on foreign keys
         # http://www.sqlite.org/foreignkeys.html
@@ -313,22 +318,23 @@ class SQLite(SQLInterface):
         """
         field_type = ""
         is_pk = field.options.get('pk', False)
+        interface_type = field.interface_type
 
-        if issubclass(field.type, bool):
+        if issubclass(interface_type, bool):
             field_type = 'BOOLEAN'
 
-        elif issubclass(field.type, long):
+        elif issubclass(interface_type, long):
             if is_pk:
                 field_type = 'INTEGER PRIMARY KEY'
             else:
                 field_type = 'BIGINT'
 
-        elif issubclass(field.type, int):
+        elif issubclass(interface_type, int):
             field_type = 'INTEGER'
             if is_pk:
                 field_type += ' PRIMARY KEY'
 
-        elif issubclass(field.type, basestring):
+        elif issubclass(interface_type, basestring):
             fo = field.options
             if field.is_ref():
                 # TODO -- 7-8-17 - this isn't a great way to do this, ideally the Field instance
@@ -354,27 +360,27 @@ class SQLite(SQLInterface):
             if is_pk:
                 field_type += ' PRIMARY KEY'
 
-        elif issubclass(field.type, datetime.datetime):
+        elif issubclass(interface_type, datetime.datetime):
             #field_type = 'DATETIME'
             field_type = 'TIMESTAMP'
 
-        elif issubclass(field.type, datetime.date):
+        elif issubclass(interface_type, datetime.date):
             field_type = 'DATE'
 
-        elif issubclass(field.type, float):
+        elif issubclass(interface_type, float):
             field_type = 'REAL'
             size = field.options.get('size', field.options.get('max_size', 0))
             if size > 6:
                 field_type = 'DOUBLE PRECISION'
 
-        elif issubclass(field.type, decimal.Decimal):
+        elif issubclass(interface_type, decimal.Decimal):
             field_type = 'NUMERIC'
 
-        elif issubclass(field.type, bytearray):
+        elif issubclass(interface_type, bytearray):
             field_type = 'BLOB'
 
         else:
-            raise ValueError('unknown python type: {}'.format(field.type.__name__))
+            raise ValueError('Unknown python type: {}'.format(interface_type.__name__))
 
         if field.required:
             field_type += ' NOT NULL'
@@ -610,3 +616,18 @@ class SQLite(SQLInterface):
         query_sort_str = "\n".join(query_sort_str)
         return query_sort_str, query_args
 
+    def _normalize_bounds_SQL(self, bounds, sql_options):
+        offset = bounds.offset
+        if sql_options.get('one_query', False):
+            limit = 1
+
+        else:
+            limit, offset = bounds.get()
+            if not bounds.has_limit():
+                limit = -1
+
+        return 'LIMIT {} OFFSET {}'.format(
+            limit,
+            offset
+        )
+
